==> haskell-resource-pool-0.2.3.2-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-resource-pool/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
key: resou_GCKRgWBJPdN4Nax9bkIYcU
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-GCKRgWBJPdN4Nax9bkIYcU
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-resource-pool/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-4273363c3eb17da3d6b84d801cb4d318
key: resou_DP0MmIFbOZE6UnJurqvzeD
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-DP0MmIFbOZE6UnJurqvzeD
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
